==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/dfa/rail_8cpp.js <==
var rail_8cpp =
[
    [ "AddDateIntroducedRailTypes", "dd/dfa/rail_8cpp.html#a09129a008e50b295b3f3f2b49dad9be7", null ],
    [ "GetBestRailtype", "dd/dfa/rail_8cpp.html#ab27bf3554532accc1948eac6cf03b938", null ],
    [ "GetCompanyRailtypes", "dd/dfa/rail_8cpp.html#ad78ead077c727135d2872fdacdbb008a", null ],
    [ "GetRailTypeByLabel", "dd/dfa/rail_8cpp.html#a8c16af99994e9ffce50927ef16d8a793", null ],
    [ "GetTileRailType", "dd/dfa/rail_8cpp.html#a764aca82ad5d1b00d6d6de809c1b2f1e", null ],
    [ "HasAnyRailtypesAvail", "dd/dfa/rail_8cpp.html#afbb82c498dc13beae88ed1e941adb98d", null ],
    [ "HasRailtypeAvail", "dd/dfa/rail_8cpp.html#adad4f06eb9fe4681f38aca5f0fc8a8b6", null ],
    [ "ValParamRailtype", "dd/dfa/rail_8cpp.html#a61120aacc59523a2bde03bda1cbab670", null ],
    [ "_corner_to_trackbits", "dd/dfa/rail_8cpp.html#a01e8b87e28a9a31f7086f2b2b59f8a59", null ],
    [ "_dir_to_diag_trackdir", "dd/dfa/rail_8cpp.html#aa0509828772402997ee6e16832328adf", null ],
    [ "_exitdir_reaches_trackdirs", "dd/dfa/rail_8cpp.html#af26210c6f9b39b74d076d05d6e74d606", null ],
    [ "_next_trackdir", "dd/dfa/rail_8cpp.html#a320d1e34434af7e1e3ddef38ec55b102", null ],
    [ "_signal_against_trackdir", "dd/dfa/rail_8cpp.html#a3047f346deae78f7e2339c615e842462", null ],
    [ "_signal_along_trackdir", "dd/dfa/rail_8cpp.html#afda00f4339ad3f950e4298950f8af7ff", null ],
    [ "_signal_on_track", "dd/dfa/rail_8cpp.html#a2f4a7ced78077cbc892a437fe2281b01", null ],
    [ "_track_crosses_trackdirs", "dd/dfa/rail_8cpp.html#aa937e45dfe8ef6cc0f03140ac454dbdb", null ],
    [ "_track_crosses_tracks", "dd/dfa/rail_8cpp.html#a9b19be25a043df67c79661badb0bce70", null ],
    [ "_track_direction_to_trackdir", "dd/dfa/rail_8cpp.html#ae254bfa477a702c6d3caa1478d4820a9", null ],
    [ "_track_enterdir_to_trackdir", "dd/dfa/rail_8cpp.html#a70a2c79f84c3b10a2ad458fe9ebb85f3", null ],
    [ "_track_exitdir_to_trackdir", "dd/dfa/rail_8cpp.html#a442a6756f9fb2a1ac7baa8c875b86124", null ],
    [ "_trackdir_to_exitdir", "dd/dfa/rail_8cpp.html#aa5446964e166828702540ed5596ba24f", null ],
    [ "_uphill_trackdirs", "dd/dfa/rail_8cpp.html#a35c9186babb51ffec75bcbbc19cf055c", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/dfa/rail_8cpp.js <==
var rail_8cpp =
[
    [ "AddDateIntroducedRailTypes", "dd/dfa/rail_8cpp.html#a09129a008e50b295b3f3f2b49dad9be7", null ],
    [ "GetCompanyRailtypes", "dd/dfa/rail_8cpp.html#a684447764fe3e07633280bb127d8e269", null ],
    [ "GetRailTypeByLabel", "dd/dfa/rail_8cpp.html#a8c16af99994e9ffce50927ef16d8a793", null ],
    [ "GetRailTypes", "dd/dfa/rail_8cpp.html#ad4668173be5c89cfe9e1709f23d6ee93", null ],
    [ "GetTileRailType", "dd/dfa/rail_8cpp.html#a764aca82ad5d1b00d6d6de809c1b2f1e", null ],
    [ "HasAnyRailtypesAvail", "dd/dfa/rail_8cpp.html#afbb82c498dc13beae88ed1e941adb98d", null ],
    [ "HasRailtypeAvail", "dd/dfa/rail_8cpp.html#adad4f06eb9fe4681f38aca5f0fc8a8b6", null ],
    [ "ValParamRailtype", "dd/dfa/rail_8cpp.html#a61120aacc59523a2bde03bda1cbab670", null ],
    [ "_corner_to_trackbits", "dd/dfa/rail_8cpp.html#a01e8b87e28a9a31f7086f2b2b59f8a59", null ],
    [ "_dir_to_diag_trackdir", "dd/dfa/rail_8cpp.html#aa0509828772402997ee6e16832328adf", null ],
    [ "_exitdir_reaches_trackdirs", "dd/dfa/rail_8cpp.html#af26210c6f9b39b74d076d05d6e74d606", null ],
    [ "_next_trackdir", "dd/dfa/rail_8cpp.html#a320d1e34434af7e1e3ddef38ec55b102", null ],
    [ "_signal_against_trackdir", "dd/dfa/rail_8cpp.html#a3047f346deae78f7e2339c615e842462", null ],
    [ "_signal_along_trackdir", "dd/dfa/rail_8cpp.html#afda00f4339ad3f950e4298950f8af7ff", null ],
    [ "_signal_on_track", "dd/dfa/rail_8cpp.html#a2f4a7ced78077cbc892a437fe2281b01", null ],
    [ "_track_crosses_trackdirs", "dd/dfa/rail_8cpp.html#aa937e45dfe8ef6cc0f03140ac454dbdb", null ],
    [ "_track_crosses_tracks", "dd/dfa/rail_8cpp.html#a9b19be25a043df67c79661badb0bce70", null ],
    [ "_track_direction_to_trackdir", "dd/dfa/rail_8cpp.html#ae254bfa477a702c6d3caa1478d4820a9", null ],
    [ "_track_enterdir_to_trackdir", "dd/dfa/rail_8cpp.html#a70a2c79f84c3b10a2ad458fe9ebb85f3", null ],
    [ "_track_exitdir_to_trackdir", "dd/dfa/rail_8cpp.html#a442a6756f9fb2a1ac7baa8c875b86124", null ],
    [ "_trackdir_to_exitdir", "dd/dfa/rail_8cpp.html#aa5446964e166828702540ed5596ba24f", null ],
    [ "_uphill_trackdirs", "dd/dfa/rail_8cpp.html#a35c9186babb51ffec75bcbbc19cf055c", null ]
];
